The ``FKMDetector`` class
#########################

.. autoclass:: pylife.stress.rainflow.FKMDetector
               :members:
               :undoc-members:
               :special-members: __init__
